@@ -1,13 +1,5 @@
 #' @name ComparisonTable
 #' @export catconttable
-#' @importFrom Hmisc label.default
-#' @importFrom Hmisc label.data.frame
-#' @importFrom Hmisc 'label<-.default'
-#' @importFrom Hmisc 'label<-.data.frame'
-#' @importFrom Hmisc print.labelled
-#' @importFrom Hmisc '[.labelled'
-#' @importFrom Hmisc latexTranslate
-#' @importFrom Hmisc smean.cl.boot
 #' 
 #' @title Comparison Tables
 #' @description Produce a table of comparisons for reports and manuscripts
@@ -199,8 +191,9 @@ catconttable <- function(data, vars, byVar, vars.cat=NULL, fisher=NULL, fisher.a
 
   ctable <- do.call("rbind", lapply(vars, var.info))
   ctable$type <- factor(ctable$type)
+  data[[byVar]] <- labelVector::set_label(data[[byVar]],
+                                          labelVector::get_label(data, byVar))
   attributes(ctable)$byVar <- data[, byVar]
-  Hmisc::label(attributes(ctable)$byVar) <- Hmisc::label(data[, byVar])
   attributes(ctable)$vars <- vars  
   return(ctable)
 }
